Algunos de los casos de aplicación de las RNA como sistemas de predicción están documentados por:  

Cuadro 1. Casos de aplicación

Actualmente, las técnicas de Soft Computing se están tomando como referente para realizar investigaciones de predicción de eventos futuros debido a que emulan el comportamiento no lineal del fenómeno para dar un pronóstico más acertado \cite{zou2007investigation}, particularmente en el campo de la hidrología, las técnicas de Soft Computing ayudan en la toma de decisiones adecuadas frente al uso del agua.

Este artículo presenta la comparación entre modelos físicos (Hec-Ras) y modelos inteligentes (RNA) con distribuciones sigmoidal-sigmoidal y sigmoidal-lineal, para la predicción de inundaciones en un tramo entre las estaciones de Puente Florencia y Tocancipá ubicadas en la cuenca alta del río Bogotá, Colombia. Adicionalmente, sugiere la generación de alertas tempranas para la prevención de desastres naturales de distinto tipo, mediante la implementación y estudio de estas técnicas.

# Antecedentes y marco de referencia

## Modelo hidrológico en HEC-RAS. 

Esta herramienta de libre uso permite hacer modelaciones hidráulicas del comportamiento del flujo permanente y no permanente de agua en un canal artificial o en un cauce natural como lo son los ríos \cite{tisseuil2010statistical}. La simulación hidráulica en este software se basa en ecuaciones diferenciales determinísticas, que permiten pronosticar la dinámica de los niveles de agua en los eventos hidrometeorológicos extremos de inundación, definiendo las cotas de inundación a través de perfiles transversales, simulando de manera aproximada el comportamiento de la dinámica del recurso hídrico y del cauce con características de: sesiones transversales con cualquier geometría a lo largo del cauce, distintas profundidades del agua y caudal variable a lo largo del cauce en condiciones de régimen de flujo sub-crítico o súper-crítico con efectos hidráulicos debido a obstáculos transversales naturales o artificiales en el cauce \cite{sarhadi2012probabilistic, mohammadi2014flood}. En cuanto a la simulación de este modelo, una metodología básica es la Ecuación de Continuidad \cite{tisseuil2010statistical} que describe la conservación de la masa para un sistema unidimensional, además de calcular términos de almacenamiento:

Ecuación (1)

Donde x = Distancia a lo largo del cauce, t = Tiempo, Q = Caudal, A= Área de la sección transversal, S = Almacenamiento y q_1= Entrada lateral por unidad de distancia.

Adicionalmente, para desarrollar una modelación en Hec-Ras se debe tener en cuenta los siguientes paramentos de calibración:

1.	Hidrogramas: gráficas que permiten observar la tasa de flujo o caudal en un lugar dado de la corriente \cite{chow1994hidrologia}. 
2.	Curvas de gasto o de calibración: representaciones gráficas de la relación existente entre el nivel de agua y su respectivo caudal **(Salazar & Chaparro, 1990) NO APARECE EN LAS CITAS**.
3.	Secciones transversales: definen la forma del río, sus características geométricas y deben estar conectadas topográficamente de modo que también se define el perfil longitudinal.
Ecuación (2) y (3)
4. Coeficientes de Manning: llamado también coeficiente de rugosidad, el cual permite estimar la resistencia al escurrimiento que posee un canal \cite{ruberto2003estudio}. Cuando se tienen varios Coeficientes de Manning (n_c) en un cauce, el canal principal es dividido en N partes, cada uno con el perímetro de humedad Pi y el coeficiente de rugosidad n_i.

Ecuación (4)

Donde n_c= Coeficiente de rugosidad compuesto, P = Perímetro de humedad del canal principal, P_i = Perímetro de humedad de la sección I y n_i = Coeficiente de rugosidad por sección.

Generalmente investigaciones realizadas en este software, evalúan el desempeño del modelo hidráulico en la predicción de inundaciones para identificar las zonas vulnerables, infraestructura crítica y el valor del uso del suelo afectado \cite{sarhadi2012probabilistic, zazo2015analysis}.  Estudios han demostrado que la modelación en Hec-Ras proporciona una estimación más adecuada de los parámetros de calibración de los recursos hidráulicos \cite{guida2015strategic}. Además, para optimizar las características geométricas de la visualización real de las zonas propensas a inundaciones, se ha implementado Hec-Ras para hacer modelaciones hidráulicas y posteriormente visualización con Sistema de Información Geográfica (GIS, por sus siglas en inglés) \cite{sarhadi2012probabilistic}. \cite{mohammadi2014flood} simuló condiciones hidráulicas de inundación y áreas inundables, para diferentes periodos de tiempo, utilizando modelos en Hec-Ras, Hec-Georas y GIS, obteniendo como resultados un análisis de riesgos y daños de las inundaciones. 

## Modelo de Redes Neuronales Artificiales

La estructura estándar de una RNA (ver Figura 1) está compuesta por un conjunto de neuronas organizadas en capas (entrada, ocultas y de salida), distribuidas jerárquicamente, constituyendo un sistema funcional autónomo \cite{chen2010development}. En este sistema inteligente se identifican los siguientes elementos: variables de entrada y salida, pesos sinápticos, que son la intensidad de interacción entre las neuronas, función de propagación, función de activación y función de salida \cite{komatsu2014artificial}.  El número de capas y neuronas es uno de los parámetros más importantes en la modelación de RNA, ya que estos determinan la eficiencia del sistema \cite{hamzaccebi2009comparison}. 

Una de las ventajas de las RNA es que pueden ser una herramienta útil para el modelado cuando la relación entre los datos de entrada y salida no es clara o en su defecto es desconocida, razón por la cual este tipo de modelos son llamados de caja negra \cite{chau2005comparison, wang2011flood}, lo que permite que a través de sus composiciones matemáticas sean capaces de modelar sistemas complejos como lo pueden ser los sistemas hidrológicos \cite{dawson2006flood}. Otro de los beneficios derivados de las RNA es su capacidad de generar salidas de una combinación específica de entradas y su capacidad de respuesta frente al manejo de datos no lineales \cite{santillan2014prediccion, cervantes2013comparacion}.

Figura 1. Estructura de una RNA \cite{chen2010development}

# Metodología

## Datos disponibles

La cuenca del río Bogotá se encuentra localizada en el departamento de Cundinamarca. Tiene una superficie total de 589 143 hectáreas que corresponden a cerca del 32% del total de la superficie departamental. El río Bogotá constituye la corriente principal de la cuenca recorriendo desde su nacimiento a los 3 300 metros sobre el nivel del mar (msnm) en el municipio de Villapinzón, hasta su desembocadura al río Magdalena a los 280 msnm en el municipio de Girardot, un total de 308 kilómetros _**(CAR, 2006)**_. El Río Bogotá está dividió en 3 subcuencas alta, media y baja. Para los efectos del presente trabajo los resultados presentados corresponden al análisis de un tramo de la cuenca alta (figura 2), ubicado entre las estaciones de Puente Florencia, en el municipio de Gachancipá (Aguas Arriba), y la estación Tocancipá en el municipio de Tocancipá (Aguas Abajo). Tramo que se caracteriza por: ofrecer registro de frecuencia horaria, estabilidad, es decir que no existe ningún embalse u otro cuerpo hídrico de gran tamaño que altere de una forma significativa el comportamiento hídrico de la cuenca y, por último, poder calcular el caudal de las 12 sub-cuencas que alimentan al río. Para el cálculo del caudal, se utilizó un método basado en los parámetros de forma y red de drenaje empleando las curvas de nivel que le dan forma a cada subcuenca y el orden del afluente \cite{horton1945erosional}. Adicionalmente, se caracterizaron los comportamientos de los caudales a través de los datos de precipitación de las áreas cercanas a estos subcaudales por medio del Método Racional, el cual se implementa para obtener los caudales máximos que se escurren a través de determinada sección \cite{mulvaney1851use}.

Figura 2. Tramo elegido (Autor con cartografía suministrada por CAR e IGAC)

El Método Racional es útil en cuencas pequeñas, en donde el límite está dado por las características de las lluvias intensas en la zona y debe ser tal que la lluvia puntual, se pueda considerar uniformemente distribuida en el área **(Fatorelli & Fernández, 2011) NO APARECE EN LAS CITAS**. La ecuación para obtener los caudales es: 

Ecuación (5)

Dónde: Q es el caudal en m3/s C es el coeficiente de escorrentía adimensional (0.025 terrenos cultivados),  I es intensidad de la lluvia en mm/hora y A es el área en hectáreas.

## Modelación en Hec-Ras

En el modelo trabajado en Hec-Ras se tuvieron en cuenta cuatro factores necesarios para establecer los parámetros del modelo: hidrogramas de las estaciones Puente Florencia y Tocancipá, curvas de gasto o de calibración, secciones transversales y Coeficiente de Manning.

Cabe resaltar que para el primer factor mencionado fue necesario simular los datos de los meses abril, mayo, octubre y noviembre, debido a que en estas fechas ocurrieron inundaciones por altas lluvias y se tomó la decisión de simular estos meses para los años 2011 y 2013.

En cuanto a las secciones transversales del modelo, se suministraron los puntos de medición obtenidos por medio de batimetría en el terreno. Se ingresaron 151 puntos en el tramo elegido, la distancia entre estos puntos varía entre 100 y 800 metros de longitud dependiendo de la forma del cauce, es decir en zonas con curvas muy cerradas se hizo la medición a distancias más cortas.  Por otro lado, el Coeficiente de Manning, fue calibrado según la superficie de rozamiento constante del agua y la superficie de menos rozamiento de zonas laterales. 

Para calibrar el modelo hidráulico simulado en Hec-Ras, se inició identificando un hidrograma simple, en el que se viera una onda sin distorsiones, en un periodo de tiempo donde se presentan caudales medios en el tramo estudiado, empleando Coeficientes de Manning en un rango de 0.021 y 0.04 en todas las secciones transversales \cite{rocha2008modelacion, cook2009effect}. Teniendo en cuenta las características anteriormente descritas se eligió el periodo del 12 al 23 de julio del año 2010, donde se ingresaron los hidrogramas de la estación de Puente Florencia y las 12 subcuencas.

Luego de la calibración del Coeficiente de Manning se simularon 6 escenarios durante diferentes periodos de tiempo (enero, abril-mayo-junio, octubre de 2011 y 2013). Respecto al parámetro ubicado en la última sección transversal correspondiente a la estación de Tocancipá o salida del modelo se dejó con profundidad normal (Normal Depth) de valor 0.0001, el cual es adecuado para situaciones donde el flujo se aproxime al uniforme \cite{tisseuil2010statistical}, como es el caso de este tramo de la cuenca alta del río Bogotá.

## Modelación en Redes Neuronales Artificiales

La simulación en RNA se realizó en el toolbox del software Matlab 2013, con los datos, normalizándolos en un rango de -1 a 1 \cite{demuth1993neural}, generando una matriz de entrada al modelo con los datos de los caudales de la estación de Puente Florencia y las 12 subcuencas del tramo escogido y un vector con los caudales de la estación de Tocancipá, el cual es la salida del modelo. Los datos se dividieron en dos partes: unos de datos de entrenamiento (70%): septiembre de 2009 a diciembre de 2012, además se incluyen los meses de febrero, marzo, julio, agosto y septiembre de 2013 y otros datos para el pronóstico (30%): meses de enero, abril, mayo, junio y octubre de los años 2011 y 2013.

La configuración del toolbox de Matlab se estableció con una clase de entrenamiento tipo back propagation \cite{kia2012artificial, chen2010development}.  Adicionalmente la función de aprendizaje elegida fue Levenberg-Marquardt (trainlm), siendo más rápida cuando se utiliza un tipo de entrenamiento back propagation, al tener formaciones de redes de gran tamaño y realizar mejor la función de ajuste para el reconocimiento de patrones del sistema trabajado \cite{demuth1993neural}. Posteriormente, se determinaron los parámetros finales para la fase de entrenamiento, los cuales fueron: un máximo de 2000 iteraciones (repeticiones) para correr el modelo hasta llegar a la validación total del procesamiento de la información, un gradiente mínimo de 1e-05, y un máximo de 6 revisiones de validación para evaluar la calidad del modelo. 

Por otro lado, para cada escenario entrenado, se utilizó una estructura multicapa \cite{kia2012artificial}; \cite{siou2011complexity} modificando el número de capas (entre 2 y 20) y de neuronas (entre 2 y 50). En total se realizaron 168 escenarios, los cuales se dividieron según su función de propagación en las capas de entrada y ocultas respectivamente, 85 con la configuración Sigmoidal-Sigmoidal, y 83 con la configuración Sigmoidal-Lineal. Para cada escenario se hizo la simulación del pronóstico y con los resultados obtenidos se hallaron cada uno de los estadísticos por medio de un programa realizado en Matlab.

## Índices de evaluación estadística de los modelos

Luego de realizar las simulaciones que arrojaban el hidrograma de salida en la estación de Tocancipá de cada uno de los periodos, se compararon con los datos reales presentados en los mismos periodos de tiempo. Esta comparación se realizó a través de seis índices estadísticos, usados en la mayoría de artículos observados y utilizados como métricas de evaluación de modelos simulados \cite{dawson2007hydrotest}, estos son:  error medio absoluto -MAE \cite{singhal2011electricity}, error medio cuadrático - MSE \cite{gomes2013optimization}, error porcentual absoluto de la media - MAPE (Lewis, 1982),  raíz cuadrada del error cuadrático medio -RMSE \cite{singhal2011electricity}, coeficiente de correlación de Pearson - CC \cite{lin2002statistical} y coeficiente de correlación de concordancia -ρ_c \cite{lawrence1989concordance}.

# Resultados y Discusión

Los resultados del modelo simulado en Hec-Ras se encuentran en el Cuadro 1, con los seis estadísticos, en los cuales se observa el ρ_c con un valor de 0.86, lo que indica que el modelo tiene una alta relación de los datos reales vs. datos simulados en cuanto a exactitud y precisión. El coeficiente de correlación (CC) indica que se presenta un error de la relación del dato simulado inferior al 10%, es decir que el error es bajo. Los valores de MAE, MSE y RMSE son bajos lo que indica diferencias pequeñas respecto a los datos reales, ello se evidencia en un buen pronóstico ya que el valor del MAPE se encuentra entre el 11% y 20% \cite{lewis1982industrial}.

Cuadro 2. Resultado estadísticos comparación datos reales vs. Datos simulados en Hec-Ras.

Luego de la simulación del modelo con RNA y la organización de los datos simulados con respecto a los estadísticos evaluados, se eligieron los 3 escenarios con mayores valores totales de los criterios estadísticos MAE, MAPE, MSE, RMSE,  CC y ρ_c, para cada una de las configuraciones de la red,  a continuación en el Cuadro 2 se recopilan los mejores 3 escenarios obtenidos en el modelo de RNA de cada configuración:

Cuadro 3. Mejores Escenarios RNA.

Luego de analizar todos los criterios estadísticos de los mejores escenarios elegidos, el mejor escenario de función de propagación Sigmoidal-Sigmoidal es el número 9, debido a que cumple con la mayor cantidad de resultados favorables en los estadísticos: menor MAE (1.90), menor MAPE (11.9%), menor MSE (10.2), menor RMSE (3.2), mayor CC (0.92) y mayor ρ_c (0.88). Tomando como referencia el resultado obtenido con el MAPE, se observa que el pronóstico arrojado es un buen pronóstico, ya que se encuentra entre un rango del 11% al 20% \cite{lewis1982industrial}, y el CC nos indica que el modelo presenta el 92% de precisión del pronóstico en cuanto a la relación de los datos reales con los simulados. En este escenario para el modelo con RNA se implementaron 20 capas y 25 neuronas, lo cual indica que con distintos números de neuronas en un modelo de tipo de percepción multicapa, es posible obtener un pronóstico más adecuado \cite{hamzaccebi2009comparison}.

En cuanto a la función de propagación Sigmoidal-Lineal se eligió el escenario 2 como el de mejor pronóstico, porque cumple con la mayor cantidad de resultados favorables en los criterios estadísticos evaluados: menor MAE (1.94), el menor MAPE (12.5%), menor MSE (10.97), menor RMSE (3.1) y el mayor CC 0.914. En este escenario se implementaron 2 capas y 50 neuronas, lo cual indica una gran variación en el número de capas respecto a la configuración Sigmoidal-Sigmoidal donde el mejor escenario tiene un número de 20 capas. Respecto al número de neuronas las dos configuraciones arrojaron el mejor pronóstico con una cantidad considerable en cada capa. 

## Comparación del Modelo Físico y los Modelos de Inteligencia Artificial.

Se encontraron investigaciones que comparan modelos matemáticos con sistemas artificiales inteligentes, en donde se concluye que los sistemas inteligentes poseen un mayor grado de relación entre el dato real vs el dato simulado, ya que permiten simular modelos no lineales, teniendo un mayor acercamiento a la realidad \cite{aqil2007analysis, firat2007river, kisi2012forecasting, karimi2013neuro}, proporcionando un mejor pronóstico que los sistemas matemáticos, como las regresiones lineales o la regresión múltiple. Sin embargo, en la bibliografía consultada no se evidencian estudios que realizará una comparación con un modelo físico, basado en hidráulica o hidrología tradicional, razón por la cual se realizó esta comparación. De igual manera, se encontró que se utilizan los criterios estadísticos tradicionales (CC, MAE, MAPE, RSME), pero ninguno con un análisis a través del coeficiente de correlación de concordancia (ρ_c), el cual indica la relación entre la precisión y exactitud del modelo \cite{firat2007river}.

A partir de los resultados obtenidos, se realizó la comparación entre el modelo físico simulado en el software hidráulico Hec-Ras y los dos modelos basados en sistemas inteligentes artificiales (RNA) simulados en Matlab. En el Cuadro 3 se encuentran los resultados de los tres mejores modelos. Los datos obtenidos sugieren que los modelos indican resultados de pronósticos muy similares mostrando en orden de efectividad, primero el RNA sigmoidal–sigmoidal, segundo el RNA sigmoidal-lineal y por último el modelo Hec-Ras. 

Cuadro 4. Resultado de los mejores Modelos Hec-Ras y RNA.

A continuación, en la Figura 4 se comparan todos los modelos utilizados en la investigación y la relación de los datos reales con los simulados. En primer lugar, con el modelo Hec-Ras (a), ANN configuración sigmoidal-sigmoidal (b) y ANN configuración sigmoidal-lineal (c). En ésta se observa que existen datos por encima y debajo de la línea de referencia, siendo mayor la cantidad por debajo. Al observar los valores mayores de caudal se puede observar que los modelos inteligentes son capaces de pronosticarlos, y aunque la dispersión de datos es alta los errores dados en los modelos indican que entre el dato pronosticado y el real el error es inferior al 10%.

Figura 3. Relación entre los datos reales vs. Datos simulados en cada uno de los modelos.

Con base en los resultados obtenidos se puede determinar que el mejor modelo es la RNA con configuración sigmoidal–sigmoidal, debido a los siguientes criterios: estabilidad y, alcance de valores máximos, poca dispersión de los datos, grado de correlación y precisión y exactitud. En primer lugar, en cuanto a la estabilidad y alcance de valores máximos, se puede observar en la figura 4b y 4 c (datos de caudales simulados vs. datos caudales reales), que los valores de caudales altos no tienen tanta variación respecto a los reales, con respecto a la dispersión de los datos alrededor de la línea de base, lo que significa que las RNA muestran una gran efectividad en eventos de inundación donde se generan caudales altos. 

En cuanto a la dispersión de los datos se observa que es reducida, lo que se evidencia en el MAE (1.90), MSE (10.17) y RMSE (3.19) que son los más bajos de todos los modelos simulados, indicando con esto que el promedio de dispersión de los datos simulados con los reales es reducido, lo que muestra su posibilidad de pronosticar con mayor precisión. En tercer lugar, el grado de correlación de los datos, posee el coeficiente de Pearson más alto con un valor de 0.921, frente a 0.907 y 0.9136 de Hec-Ras y RNA sigmoidal-lineal respectivamente. Esto indica que la relación entre los datos simulados y los reales es del 92.15% y que el error de pronóstico es inferior al 8%. En cuarto y último lugar, presenta la mejor precisión y exactitud de todos los modelos simulados, que fueron evaluados con el ρ_c, obteniendo resultados con valores de 0.877, 0.872 y 0.860 de los modelos RNA sigmoidal-sigmoidal, RNA sigmoidal-lineal y Hec-Ras respectivamente. Esto indica que el modelo de RNA es mejor que los otros dos, aunque se observa que los valores comparados con Hec-Ras son muy parecidos. La realidad es que cuando se evalúan valores elevados o extremos el modelo hidráulico no es capaz de seguir los valores reales, lo que sí puede hacer con valores medios y bajos de ρ_c. 

# Validación del modelo

Los resultados obtenidos en esta investigación, fueron comparados con el test de hidrología “HydroTest Statistical Assessment of Hydrological Forecasts” el cual evalúa 20 métricas estadísticas reportadas en estudios de modelamiento hidrológico \cite{dawson2007hydrotest}. Se realizaron cuatro test donde se ingresaron los datos reales y los datos modelados (Hec-Ras, RNA Sig – Lin y RNA Sig – Sig). En el Cuadro 4 se muestra los valores comparados de las estadísticas calculadas en Matlab, con las calculadas con el Hydrotest además de tres criterios estadísticos que se evaluaron adicionalmente, el coeficiente de determinación (RSQR) \cite{pearson1896mathematical}, el índice de acuerdo de Willmott (IoAd) y el coeficiente de eficiencia (CE) \cite{bortone2011libreria}.

Cuadro 5. Comparación de las estadísticas generadas en la modelación vs. Estadísticas generadas en Hydro Test.

Al comparar los valores de los estadísticos CC, MAE y RMSE se observa que son muy cercanos, variando en décimas o centésimas, indicando que fueron hallados correctamente en los análisis realizados anteriormente. El RSQR de los resultados, se encuentran en un intervalo de 0.801 a 0.847, lo que indica que son modelos satisfactorios, aunque cabe anotar que el modelo RNA de configuración sigmoidal – sigmoidal está muy cerca de ser un buen modelo de pronóstico. Desde el índice de acuerdo de Willmott (IoAd), todos los modelos simulados son buenos al tener valores superiores a 0.9 y en general muy similares en un intervalo de 0.93 a 0.95. El coeficiente de eficiencia (CE) si muestra una gran diferencia entre los cuatro modelos de predicción, rechazando el modelo físico de Hec-Ras (0.7837) con un valor inferior a 0.8. Los otros dos modelos que son los de sistemas inteligentes artificiales, se describen como satisfactorios con valores que se encuentran en el intervalo de 0.80 a 0.84, siendo este último el valor del modelo RNA sigmoidal – sigmoidal (Dawson et al. 2007).

# Conclusiones

Al comparar modelos hidráulicos y modelos basados en sistemas artificiales inteligentes, se puede afirmar que los modelos inteligentes son mejores que los primeros en cuanto a la efectividad en pronosticar valores de caudales de eventos extremos de manera más precisa y exacta. El estudio en el cual se simuló el comportamiento de un tramo del río Bogotá basado en históricos de caudal, arrojaron resultados estadísticos que demuestran pronósticos muy cercanos a los datos reales y la efectividad de las técnicas (MAPE entre 11.95 y 12.51, que indica un buen pronóstico; CC entre 0.90 y 0.92, demuestra buena relación entre los datos reales y los simulados; ρ_c entre 0.84 y 0.87 qué significa precisión y exactitud en el pronóstico y RSqr, IoAd y CE mayores a 0.8, muestra un pronóstico satisfactorio).  Sin embargo, se debe destacar que la diferencia del modelo simulado en Hec-Ras y el mejor de los inteligentes de RNA simulados en Matlab, no es lo bastante significativa al comparar sus estadísticas, lo que quiere decir que el modelo de RNA es más eficiente al emular comportamientos hidráulicos de las cuencas.

Como se observa en el análisis de resultados, se utilizó el estadístico Coeficiente de Correlación de Concordancia -CCC, el cual usualmente es poco utilizado en pronósticos de inundaciones, siendo su principal aplicación en el sector médico. Dicho coeficiente logra evaluar la relación entre la precisión y exactitud del modelo entre los datos simulados y los datos reales, para el caso de las RNA su valor osciló entre 0.84 y 0.88, valores que indican que los modelos simulados son muy precisos y exactos con relación a la recta y=x.

Es importante indicar que existe una relación entre las variables hidrometeorológicas y los fenómenos de inundación, ya que al comprender esta relación se puede entender cuál es el funcionamiento de un sistema hídrico natural. En la presente investigación se observó que la relación entre estas variables con las zonas de inundación es proporcional, mostrando que, al aumentar variables como el caudal o la precipitación, se hacían evidentes fenómenos de inundación.

Se observa que las técnicas de inteligencia artificial como las RNA pueden ser iguales o mejores que los modelos hidrológicos comunes en ríos con comportamientos variantes, dados por el relieve de un país como Colombia y que la aplicación de este tipo de soluciones puede ser una buena alternativa para la generación de sistemas de alertas tempranas, a través de la integración sistemas inteligentes artificiales para hacer el pronóstico. De igual manera es importante resaltar que las RNA no requieren datos de topografía y pueden trabajar con información histórica incompleta generando de igual manera resultados comparables o mejores a los pronósticos tradicionales que usan modelos físicos.

Así mismo, queda bastante por investigar en el uso de estas nuevas técnicas en países de relieves tan diversos como los de Suramérica, es necesario continuar validando estos métodos con la integración de más variables no solo hidrometeorológicas sino sociales, logísticas y culturales, lo que podría generar mayores desarrollos tecnológicos para la creación de alertas tempranas y la prevención de desastres naturales.